"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Cdn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CDN_WEB_APPLICATION_FIREWALL_POLICIES_FIELD_NUMBER: builtins.int
    PROFILES_FIELD_NUMBER: builtins.int
    PROFILES_ENDPOINTS_FIELD_NUMBER: builtins.int
    PROFILES_ENDPOINTS_CUSTOM_DOMAINS_FIELD_NUMBER: builtins.int
    PROFILES_ENDPOINTS_ORIGIN_GROUPS_FIELD_NUMBER: builtins.int
    PROFILES_ENDPOINTS_ORIGINS_FIELD_NUMBER: builtins.int
    @property
    def cdn_web_application_firewall_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CdnWebApplicationFirewallPolicies]: ...
    @property
    def profiles(self) -> global___Profiles: ...
    @property
    def profiles_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesEndpoints]: ...
    @property
    def profiles_endpoints_custom_domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesEndpointsCustomDomains]: ...
    @property
    def profiles_endpoints_origin_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesEndpointsOriginGroups]: ...
    @property
    def profiles_endpoints_origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesEndpointsOrigins]: ...
    def __init__(
        self,
        *,
        cdn_web_application_firewall_policies: collections.abc.Iterable[global___CdnWebApplicationFirewallPolicies] | None = ...,
        profiles: global___Profiles | None = ...,
        profiles_endpoints: collections.abc.Iterable[global___ProfilesEndpoints] | None = ...,
        profiles_endpoints_custom_domains: collections.abc.Iterable[global___ProfilesEndpointsCustomDomains] | None = ...,
        profiles_endpoints_origin_groups: collections.abc.Iterable[global___ProfilesEndpointsOriginGroups] | None = ...,
        profiles_endpoints_origins: collections.abc.Iterable[global___ProfilesEndpointsOrigins] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["profiles", b"profiles"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cdn_web_application_firewall_policies", b"cdn_web_application_firewall_policies", "profiles", b"profiles", "profiles_endpoints", b"profiles_endpoints", "profiles_endpoints_custom_domains", b"profiles_endpoints_custom_domains", "profiles_endpoints_origin_groups", b"profiles_endpoints_origin_groups", "profiles_endpoints_origins", b"profiles_endpoints_origins"]) -> None: ...

global___Microsoft_Cdn = Microsoft_Cdn

@typing_extensions.final
class ProfilesSecurityPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def parameters(self) -> global___SecurityPolicyParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        parameters: global___SecurityPolicyParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___ProfilesSecurityPolicies = ProfilesSecurityPolicies

@typing_extensions.final
class SecurityPolicyParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___SecurityPolicyParameters = SecurityPolicyParameters

@typing_extensions.final
class ProfilesSecrets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def parameters(self) -> global___SecretParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        parameters: global___SecretParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___ProfilesSecrets = ProfilesSecrets

@typing_extensions.final
class SecretParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___SecretParameters = SecretParameters

@typing_extensions.final
class ProfilesRuleSetsRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    MATCH_PROCESSING_BEHAVIOR_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryRuleAction1]: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryRuleCondition]: ...
    match_processing_behavior: builtins.str
    order: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        actions: collections.abc.Iterable[global___DeliveryRuleAction1] | None = ...,
        conditions: collections.abc.Iterable[global___DeliveryRuleCondition] | None = ...,
        match_processing_behavior: builtins.str = ...,
        order: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "conditions", b"conditions", "match_processing_behavior", b"match_processing_behavior", "name", b"name", "order", b"order", "resource_info", b"resource_info"]) -> None: ...

global___ProfilesRuleSetsRules = ProfilesRuleSetsRules

@typing_extensions.final
class ProfilesRuleSets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROFILES_RULE_SETS_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def profiles_rule_sets_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesRuleSetsRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        profiles_rule_sets_rules: collections.abc.Iterable[global___ProfilesRuleSetsRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "profiles_rule_sets_rules", b"profiles_rule_sets_rules", "resource_info", b"resource_info"]) -> None: ...

global___ProfilesRuleSets = ProfilesRuleSets

@typing_extensions.final
class ProfilesOriginGroupsOrigins(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SharedPrivateLinkResourceEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_ORIGIN_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    ENFORCE_CERTIFICATE_NAME_CHECK_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    HTTP_PORT_FIELD_NUMBER: builtins.int
    HTTPS_PORT_FIELD_NUMBER: builtins.int
    ORIGIN_HOST_HEADER_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    SHARED_PRIVATE_LINK_RESOURCE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def azure_origin(self) -> global___ResourceReference: ...
    enabled_state: builtins.str
    enforce_certificate_name_check: builtins.bool
    host_name: builtins.str
    http_port: builtins.int
    https_port: builtins.int
    origin_host_header: builtins.str
    priority: builtins.int
    @property
    def shared_private_link_resource(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_origin: global___ResourceReference | None = ...,
        enabled_state: builtins.str = ...,
        enforce_certificate_name_check: builtins.bool = ...,
        host_name: builtins.str = ...,
        http_port: builtins.int = ...,
        https_port: builtins.int = ...,
        origin_host_header: builtins.str = ...,
        priority: builtins.int = ...,
        shared_private_link_resource: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_origin", b"azure_origin", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_origin", b"azure_origin", "enabled_state", b"enabled_state", "enforce_certificate_name_check", b"enforce_certificate_name_check", "host_name", b"host_name", "http_port", b"http_port", "https_port", b"https_port", "name", b"name", "origin_host_header", b"origin_host_header", "priority", b"priority", "resource_info", b"resource_info", "shared_private_link_resource", b"shared_private_link_resource", "weight", b"weight"]) -> None: ...

global___ProfilesOriginGroupsOrigins = ProfilesOriginGroupsOrigins

@typing_extensions.final
class ProfilesOriginGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HEALTH_PROBE_SETTINGS_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SETTINGS_FIELD_NUMBER: builtins.int
    RESPONSE_BASED_AFD_ORIGIN_ERROR_DETECTION_SETTINGS_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_STATE_FIELD_NUMBER: builtins.int
    TRAFFIC_RESTORATION_TIME_TO_HEALED_OR_NEW_ENDPOINTS_IN_MINUTES_FIELD_NUMBER: builtins.int
    PROFILES_ORIGIN_GROUPS_ORIGINS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def health_probe_settings(self) -> global___HealthProbeParameters: ...
    @property
    def load_balancing_settings(self) -> global___LoadBalancingSettingsParameters: ...
    @property
    def response_based_afd_origin_error_detection_settings(self) -> global___ResponseBasedOriginErrorDetectionParameters: ...
    session_affinity_state: builtins.str
    traffic_restoration_time_to_healed_or_new_endpoints_in_minutes: builtins.int
    @property
    def profiles_origin_groups_origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesOriginGroupsOrigins]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        health_probe_settings: global___HealthProbeParameters | None = ...,
        load_balancing_settings: global___LoadBalancingSettingsParameters | None = ...,
        response_based_afd_origin_error_detection_settings: global___ResponseBasedOriginErrorDetectionParameters | None = ...,
        session_affinity_state: builtins.str = ...,
        traffic_restoration_time_to_healed_or_new_endpoints_in_minutes: builtins.int = ...,
        profiles_origin_groups_origins: collections.abc.Iterable[global___ProfilesOriginGroupsOrigins] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "load_balancing_settings", b"load_balancing_settings", "resource_info", b"resource_info", "response_based_afd_origin_error_detection_settings", b"response_based_afd_origin_error_detection_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "load_balancing_settings", b"load_balancing_settings", "name", b"name", "profiles_origin_groups_origins", b"profiles_origin_groups_origins", "resource_info", b"resource_info", "response_based_afd_origin_error_detection_settings", b"response_based_afd_origin_error_detection_settings", "session_affinity_state", b"session_affinity_state", "traffic_restoration_time_to_healed_or_new_endpoints_in_minutes", b"traffic_restoration_time_to_healed_or_new_endpoints_in_minutes"]) -> None: ...

global___ProfilesOriginGroups = ProfilesOriginGroups

@typing_extensions.final
class LoadBalancingSettingsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_LATENCY_IN_MILLISECONDS_FIELD_NUMBER: builtins.int
    SAMPLE_SIZE_FIELD_NUMBER: builtins.int
    SUCCESSFUL_SAMPLES_REQUIRED_FIELD_NUMBER: builtins.int
    additional_latency_in_milliseconds: builtins.int
    sample_size: builtins.int
    successful_samples_required: builtins.int
    def __init__(
        self,
        *,
        additional_latency_in_milliseconds: builtins.int = ...,
        sample_size: builtins.int = ...,
        successful_samples_required: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_latency_in_milliseconds", b"additional_latency_in_milliseconds", "sample_size", b"sample_size", "successful_samples_required", b"successful_samples_required"]) -> None: ...

global___LoadBalancingSettingsParameters = LoadBalancingSettingsParameters

@typing_extensions.final
class ProfilesEndpointsOrigins(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    HTTP_PORT_FIELD_NUMBER: builtins.int
    HTTPS_PORT_FIELD_NUMBER: builtins.int
    ORIGIN_HOST_HEADER_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_ALIAS_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_APPROVAL_MESSAGE_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_LOCATION_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_RESOURCE_ID_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    enabled: builtins.bool
    host_name: builtins.str
    http_port: builtins.int
    https_port: builtins.int
    origin_host_header: builtins.str
    priority: builtins.int
    private_link_alias: builtins.str
    private_link_approval_message: builtins.str
    private_link_location: builtins.str
    private_link_resource_id: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        enabled: builtins.bool = ...,
        host_name: builtins.str = ...,
        http_port: builtins.int = ...,
        https_port: builtins.int = ...,
        origin_host_header: builtins.str = ...,
        priority: builtins.int = ...,
        private_link_alias: builtins.str = ...,
        private_link_approval_message: builtins.str = ...,
        private_link_location: builtins.str = ...,
        private_link_resource_id: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "host_name", b"host_name", "http_port", b"http_port", "https_port", b"https_port", "name", b"name", "origin_host_header", b"origin_host_header", "priority", b"priority", "private_link_alias", b"private_link_alias", "private_link_approval_message", b"private_link_approval_message", "private_link_location", b"private_link_location", "private_link_resource_id", b"private_link_resource_id", "resource_info", b"resource_info", "weight", b"weight"]) -> None: ...

global___ProfilesEndpointsOrigins = ProfilesEndpointsOrigins

@typing_extensions.final
class ProfilesEndpointsOriginGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HEALTH_PROBE_SETTINGS_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    RESPONSE_BASED_ORIGIN_ERROR_DETECTION_SETTINGS_FIELD_NUMBER: builtins.int
    TRAFFIC_RESTORATION_TIME_TO_HEALED_OR_NEW_ENDPOINTS_IN_MINUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def health_probe_settings(self) -> global___HealthProbeParameters: ...
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    @property
    def response_based_origin_error_detection_settings(self) -> global___ResponseBasedOriginErrorDetectionParameters: ...
    traffic_restoration_time_to_healed_or_new_endpoints_in_minutes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        health_probe_settings: global___HealthProbeParameters | None = ...,
        origins: collections.abc.Iterable[global___ResourceReference] | None = ...,
        response_based_origin_error_detection_settings: global___ResponseBasedOriginErrorDetectionParameters | None = ...,
        traffic_restoration_time_to_healed_or_new_endpoints_in_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "resource_info", b"resource_info", "response_based_origin_error_detection_settings", b"response_based_origin_error_detection_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "name", b"name", "origins", b"origins", "resource_info", b"resource_info", "response_based_origin_error_detection_settings", b"response_based_origin_error_detection_settings", "traffic_restoration_time_to_healed_or_new_endpoints_in_minutes", b"traffic_restoration_time_to_healed_or_new_endpoints_in_minutes"]) -> None: ...

global___ProfilesEndpointsOriginGroups = ProfilesEndpointsOriginGroups

@typing_extensions.final
class ProfilesEndpointsCustomDomains(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    host_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        host_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_name", b"host_name", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ProfilesEndpointsCustomDomains = ProfilesEndpointsCustomDomains

@typing_extensions.final
class ProfilesEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTENT_TYPES_TO_COMPRESS_FIELD_NUMBER: builtins.int
    DEFAULT_ORIGIN_GROUP_FIELD_NUMBER: builtins.int
    DELIVERY_POLICY_FIELD_NUMBER: builtins.int
    GEO_FILTERS_FIELD_NUMBER: builtins.int
    IS_COMPRESSION_ENABLED_FIELD_NUMBER: builtins.int
    IS_HTTP_ALLOWED_FIELD_NUMBER: builtins.int
    IS_HTTPS_ALLOWED_FIELD_NUMBER: builtins.int
    OPTIMIZATION_TYPE_FIELD_NUMBER: builtins.int
    ORIGIN_GROUPS_FIELD_NUMBER: builtins.int
    ORIGIN_HOST_HEADER_FIELD_NUMBER: builtins.int
    ORIGIN_PATH_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    PROBE_PATH_FIELD_NUMBER: builtins.int
    QUERY_STRING_CACHING_BEHAVIOR_FIELD_NUMBER: builtins.int
    URL_SIGNING_KEYS_FIELD_NUMBER: builtins.int
    WEB_APPLICATION_FIREWALL_POLICY_LINK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def content_types_to_compress(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def default_origin_group(self) -> global___ResourceReference: ...
    @property
    def delivery_policy(self) -> global___EndpointPropertiesUpdateParametersDeliveryPolicy: ...
    @property
    def geo_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GeoFilter]: ...
    is_compression_enabled: builtins.bool
    is_http_allowed: builtins.bool
    is_https_allowed: builtins.bool
    optimization_type: builtins.str
    @property
    def origin_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeepCreatedOriginGroup]: ...
    origin_host_header: builtins.str
    origin_path: builtins.str
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeepCreatedOrigin]: ...
    probe_path: builtins.str
    query_string_caching_behavior: builtins.str
    @property
    def url_signing_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UrlSigningKey]: ...
    @property
    def web_application_firewall_policy_link(self) -> global___EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        content_types_to_compress: collections.abc.Iterable[builtins.str] | None = ...,
        default_origin_group: global___ResourceReference | None = ...,
        delivery_policy: global___EndpointPropertiesUpdateParametersDeliveryPolicy | None = ...,
        geo_filters: collections.abc.Iterable[global___GeoFilter] | None = ...,
        is_compression_enabled: builtins.bool = ...,
        is_http_allowed: builtins.bool = ...,
        is_https_allowed: builtins.bool = ...,
        optimization_type: builtins.str = ...,
        origin_groups: collections.abc.Iterable[global___DeepCreatedOriginGroup] | None = ...,
        origin_host_header: builtins.str = ...,
        origin_path: builtins.str = ...,
        origins: collections.abc.Iterable[global___DeepCreatedOrigin] | None = ...,
        probe_path: builtins.str = ...,
        query_string_caching_behavior: builtins.str = ...,
        url_signing_keys: collections.abc.Iterable[global___UrlSigningKey] | None = ...,
        web_application_firewall_policy_link: global___EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_origin_group", b"default_origin_group", "delivery_policy", b"delivery_policy", "resource_info", b"resource_info", "web_application_firewall_policy_link", b"web_application_firewall_policy_link"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_types_to_compress", b"content_types_to_compress", "default_origin_group", b"default_origin_group", "delivery_policy", b"delivery_policy", "geo_filters", b"geo_filters", "is_compression_enabled", b"is_compression_enabled", "is_http_allowed", b"is_http_allowed", "is_https_allowed", b"is_https_allowed", "location", b"location", "name", b"name", "optimization_type", b"optimization_type", "origin_groups", b"origin_groups", "origin_host_header", b"origin_host_header", "origin_path", b"origin_path", "origins", b"origins", "probe_path", b"probe_path", "query_string_caching_behavior", b"query_string_caching_behavior", "resource_info", b"resource_info", "tags", b"tags", "url_signing_keys", b"url_signing_keys", "web_application_firewall_policy_link", b"web_application_firewall_policy_link"]) -> None: ...

global___ProfilesEndpoints = ProfilesEndpoints

@typing_extensions.final
class EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink = EndpointPropertiesUpdateParametersWebApplicationFirewallPolicyLink

@typing_extensions.final
class UrlSigningKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    KEY_SOURCE_PARAMETERS_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    @property
    def key_source_parameters(self) -> global___KeyVaultSigningKeyParameters: ...
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        key_source_parameters: global___KeyVaultSigningKeyParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_source_parameters", b"key_source_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_id", b"key_id", "key_source_parameters", b"key_source_parameters"]) -> None: ...

global___UrlSigningKey = UrlSigningKey

@typing_extensions.final
class KeyVaultSigningKeyParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    SECRET_VERSION_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    VAULT_NAME_FIELD_NUMBER: builtins.int
    resource_group_name: builtins.str
    secret_name: builtins.str
    secret_version: builtins.str
    subscription_id: builtins.str
    type_name: builtins.str
    vault_name: builtins.str
    def __init__(
        self,
        *,
        resource_group_name: builtins.str = ...,
        secret_name: builtins.str = ...,
        secret_version: builtins.str = ...,
        subscription_id: builtins.str = ...,
        type_name: builtins.str = ...,
        vault_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_group_name", b"resource_group_name", "secret_name", b"secret_name", "secret_version", b"secret_version", "subscription_id", b"subscription_id", "type_name", b"type_name", "vault_name", b"vault_name"]) -> None: ...

global___KeyVaultSigningKeyParameters = KeyVaultSigningKeyParameters

@typing_extensions.final
class DeepCreatedOrigin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    HTTP_PORT_FIELD_NUMBER: builtins.int
    HTTPS_PORT_FIELD_NUMBER: builtins.int
    ORIGIN_HOST_HEADER_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_ALIAS_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_APPROVAL_MESSAGE_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_LOCATION_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_RESOURCE_ID_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    name: builtins.str
    enabled: builtins.bool
    host_name: builtins.str
    http_port: builtins.int
    https_port: builtins.int
    origin_host_header: builtins.str
    priority: builtins.int
    private_link_alias: builtins.str
    private_link_approval_message: builtins.str
    private_link_location: builtins.str
    private_link_resource_id: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        enabled: builtins.bool = ...,
        host_name: builtins.str = ...,
        http_port: builtins.int = ...,
        https_port: builtins.int = ...,
        origin_host_header: builtins.str = ...,
        priority: builtins.int = ...,
        private_link_alias: builtins.str = ...,
        private_link_approval_message: builtins.str = ...,
        private_link_location: builtins.str = ...,
        private_link_resource_id: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "host_name", b"host_name", "http_port", b"http_port", "https_port", b"https_port", "name", b"name", "origin_host_header", b"origin_host_header", "priority", b"priority", "private_link_alias", b"private_link_alias", "private_link_approval_message", b"private_link_approval_message", "private_link_location", b"private_link_location", "private_link_resource_id", b"private_link_resource_id", "weight", b"weight"]) -> None: ...

global___DeepCreatedOrigin = DeepCreatedOrigin

@typing_extensions.final
class DeepCreatedOriginGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    HEALTH_PROBE_SETTINGS_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    RESPONSE_BASED_ORIGIN_ERROR_DETECTION_SETTINGS_FIELD_NUMBER: builtins.int
    TRAFFIC_RESTORATION_TIME_TO_HEALED_OR_NEW_ENDPOINTS_IN_MINUTES_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def health_probe_settings(self) -> global___HealthProbeParameters: ...
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    @property
    def response_based_origin_error_detection_settings(self) -> global___ResponseBasedOriginErrorDetectionParameters: ...
    traffic_restoration_time_to_healed_or_new_endpoints_in_minutes: builtins.int
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        health_probe_settings: global___HealthProbeParameters | None = ...,
        origins: collections.abc.Iterable[global___ResourceReference] | None = ...,
        response_based_origin_error_detection_settings: global___ResponseBasedOriginErrorDetectionParameters | None = ...,
        traffic_restoration_time_to_healed_or_new_endpoints_in_minutes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "response_based_origin_error_detection_settings", b"response_based_origin_error_detection_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_probe_settings", b"health_probe_settings", "name", b"name", "origins", b"origins", "response_based_origin_error_detection_settings", b"response_based_origin_error_detection_settings", "traffic_restoration_time_to_healed_or_new_endpoints_in_minutes", b"traffic_restoration_time_to_healed_or_new_endpoints_in_minutes"]) -> None: ...

global___DeepCreatedOriginGroup = DeepCreatedOriginGroup

@typing_extensions.final
class ResponseBasedOriginErrorDetectionParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_ERROR_RANGES_FIELD_NUMBER: builtins.int
    RESPONSE_BASED_DETECTED_ERROR_TYPES_FIELD_NUMBER: builtins.int
    RESPONSE_BASED_FAILOVER_THRESHOLD_PERCENTAGE_FIELD_NUMBER: builtins.int
    @property
    def http_error_ranges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpErrorRangeParameters]: ...
    response_based_detected_error_types: builtins.str
    response_based_failover_threshold_percentage: builtins.int
    def __init__(
        self,
        *,
        http_error_ranges: collections.abc.Iterable[global___HttpErrorRangeParameters] | None = ...,
        response_based_detected_error_types: builtins.str = ...,
        response_based_failover_threshold_percentage: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_error_ranges", b"http_error_ranges", "response_based_detected_error_types", b"response_based_detected_error_types", "response_based_failover_threshold_percentage", b"response_based_failover_threshold_percentage"]) -> None: ...

global___ResponseBasedOriginErrorDetectionParameters = ResponseBasedOriginErrorDetectionParameters

@typing_extensions.final
class HttpErrorRangeParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEGIN_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    begin: builtins.int
    end: builtins.int
    def __init__(
        self,
        *,
        begin: builtins.int = ...,
        end: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin", b"begin", "end", b"end"]) -> None: ...

global___HttpErrorRangeParameters = HttpErrorRangeParameters

@typing_extensions.final
class HealthProbeParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROBE_INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    PROBE_PATH_FIELD_NUMBER: builtins.int
    PROBE_PROTOCOL_FIELD_NUMBER: builtins.int
    PROBE_REQUEST_TYPE_FIELD_NUMBER: builtins.int
    probe_interval_in_seconds: builtins.int
    probe_path: builtins.str
    probe_protocol: builtins.str
    probe_request_type: builtins.str
    def __init__(
        self,
        *,
        probe_interval_in_seconds: builtins.int = ...,
        probe_path: builtins.str = ...,
        probe_protocol: builtins.str = ...,
        probe_request_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["probe_interval_in_seconds", b"probe_interval_in_seconds", "probe_path", b"probe_path", "probe_protocol", b"probe_protocol", "probe_request_type", b"probe_request_type"]) -> None: ...

global___HealthProbeParameters = HealthProbeParameters

@typing_extensions.final
class GeoFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    COUNTRY_CODES_FIELD_NUMBER: builtins.int
    RELATIVE_PATH_FIELD_NUMBER: builtins.int
    action: builtins.str
    @property
    def country_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    relative_path: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        country_codes: collections.abc.Iterable[builtins.str] | None = ...,
        relative_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "country_codes", b"country_codes", "relative_path", b"relative_path"]) -> None: ...

global___GeoFilter = GeoFilter

@typing_extensions.final
class EndpointPropertiesUpdateParametersDeliveryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryRule]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        rules: collections.abc.Iterable[global___DeliveryRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "rules", b"rules"]) -> None: ...

global___EndpointPropertiesUpdateParametersDeliveryPolicy = EndpointPropertiesUpdateParametersDeliveryPolicy

@typing_extensions.final
class DeliveryRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryRuleAction1]: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryRuleCondition]: ...
    name: builtins.str
    order: builtins.int
    def __init__(
        self,
        *,
        actions: collections.abc.Iterable[global___DeliveryRuleAction1] | None = ...,
        conditions: collections.abc.Iterable[global___DeliveryRuleCondition] | None = ...,
        name: builtins.str = ...,
        order: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "conditions", b"conditions", "name", b"name", "order", b"order"]) -> None: ...

global___DeliveryRule = DeliveryRule

@typing_extensions.final
class DeliveryRuleCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeliveryRuleCondition = DeliveryRuleCondition

@typing_extensions.final
class DeliveryRuleAction1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeliveryRuleAction1 = DeliveryRuleAction1

@typing_extensions.final
class ProfilesCustomDomains(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AZURE_DNS_ZONE_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    PRE_VALIDATED_CUSTOM_DOMAIN_RESOURCE_ID_FIELD_NUMBER: builtins.int
    TLS_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def azure_dns_zone(self) -> global___ResourceReference: ...
    host_name: builtins.str
    @property
    def pre_validated_custom_domain_resource_id(self) -> global___ResourceReference: ...
    @property
    def tls_settings(self) -> global___AFDDomainHttpsParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        azure_dns_zone: global___ResourceReference | None = ...,
        host_name: builtins.str = ...,
        pre_validated_custom_domain_resource_id: global___ResourceReference | None = ...,
        tls_settings: global___AFDDomainHttpsParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_dns_zone", b"azure_dns_zone", "pre_validated_custom_domain_resource_id", b"pre_validated_custom_domain_resource_id", "resource_info", b"resource_info", "tls_settings", b"tls_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_dns_zone", b"azure_dns_zone", "host_name", b"host_name", "name", b"name", "pre_validated_custom_domain_resource_id", b"pre_validated_custom_domain_resource_id", "resource_info", b"resource_info", "tls_settings", b"tls_settings"]) -> None: ...

global___ProfilesCustomDomains = ProfilesCustomDomains

@typing_extensions.final
class AFDDomainHttpsParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_TYPE_FIELD_NUMBER: builtins.int
    MINIMUM_TLS_VERSION_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    certificate_type: builtins.str
    minimum_tls_version: builtins.str
    @property
    def secret(self) -> global___ResourceReference: ...
    def __init__(
        self,
        *,
        certificate_type: builtins.str = ...,
        minimum_tls_version: builtins.str = ...,
        secret: global___ResourceReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_type", b"certificate_type", "minimum_tls_version", b"minimum_tls_version", "secret", b"secret"]) -> None: ...

global___AFDDomainHttpsParameters = AFDDomainHttpsParameters

@typing_extensions.final
class ProfilesAfdEndpointsRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CACHE_CONFIGURATION_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAINS_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    FORWARDING_PROTOCOL_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    LINK_TO_DEFAULT_DOMAIN_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_FIELD_NUMBER: builtins.int
    ORIGIN_PATH_FIELD_NUMBER: builtins.int
    PATTERNS_TO_MATCH_FIELD_NUMBER: builtins.int
    RULE_SETS_FIELD_NUMBER: builtins.int
    SUPPORTED_PROTOCOLS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def cache_configuration(self) -> global___AfdRouteCacheConfiguration: ...
    @property
    def custom_domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ActivatedResourceReference]: ...
    enabled_state: builtins.str
    forwarding_protocol: builtins.str
    https_redirect: builtins.str
    link_to_default_domain: builtins.str
    @property
    def origin_group(self) -> global___ResourceReference: ...
    origin_path: builtins.str
    @property
    def patterns_to_match(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceReference]: ...
    @property
    def supported_protocols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        cache_configuration: global___AfdRouteCacheConfiguration | None = ...,
        custom_domains: collections.abc.Iterable[global___ActivatedResourceReference] | None = ...,
        enabled_state: builtins.str = ...,
        forwarding_protocol: builtins.str = ...,
        https_redirect: builtins.str = ...,
        link_to_default_domain: builtins.str = ...,
        origin_group: global___ResourceReference | None = ...,
        origin_path: builtins.str = ...,
        patterns_to_match: collections.abc.Iterable[builtins.str] | None = ...,
        rule_sets: collections.abc.Iterable[global___ResourceReference] | None = ...,
        supported_protocols: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_configuration", b"cache_configuration", "origin_group", b"origin_group", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_configuration", b"cache_configuration", "custom_domains", b"custom_domains", "enabled_state", b"enabled_state", "forwarding_protocol", b"forwarding_protocol", "https_redirect", b"https_redirect", "link_to_default_domain", b"link_to_default_domain", "name", b"name", "origin_group", b"origin_group", "origin_path", b"origin_path", "patterns_to_match", b"patterns_to_match", "resource_info", b"resource_info", "rule_sets", b"rule_sets", "supported_protocols", b"supported_protocols"]) -> None: ...

global___ProfilesAfdEndpointsRoutes = ProfilesAfdEndpointsRoutes

@typing_extensions.final
class ResourceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ResourceReference = ResourceReference

@typing_extensions.final
class ActivatedResourceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ActivatedResourceReference = ActivatedResourceReference

@typing_extensions.final
class AfdRouteCacheConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CompressionSettingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMPRESSION_SETTINGS_FIELD_NUMBER: builtins.int
    QUERY_PARAMETERS_FIELD_NUMBER: builtins.int
    QUERY_STRING_CACHING_BEHAVIOR_FIELD_NUMBER: builtins.int
    @property
    def compression_settings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_parameters: builtins.str
    query_string_caching_behavior: builtins.str
    def __init__(
        self,
        *,
        compression_settings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_parameters: builtins.str = ...,
        query_string_caching_behavior: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compression_settings", b"compression_settings", "query_parameters", b"query_parameters", "query_string_caching_behavior", b"query_string_caching_behavior"]) -> None: ...

global___AfdRouteCacheConfiguration = AfdRouteCacheConfiguration

@typing_extensions.final
class ProfilesAfdEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    ORIGIN_RESPONSE_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROFILES_AFD_ENDPOINTS_ROUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    enabled_state: builtins.str
    origin_response_timeout_seconds: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def profiles_afd_endpoints_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesAfdEndpointsRoutes]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        enabled_state: builtins.str = ...,
        origin_response_timeout_seconds: builtins.int = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        profiles_afd_endpoints_routes: collections.abc.Iterable[global___ProfilesAfdEndpointsRoutes] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled_state", b"enabled_state", "location", b"location", "name", b"name", "origin_response_timeout_seconds", b"origin_response_timeout_seconds", "profiles_afd_endpoints_routes", b"profiles_afd_endpoints_routes", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ProfilesAfdEndpoints = ProfilesAfdEndpoints

@typing_extensions.final
class Profiles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    ORIGIN_RESPONSE_TIMEOUT_SECONDS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROFILES_CUSTOM_DOMAINS_FIELD_NUMBER: builtins.int
    PROFILES_AFD_ENDPOINTS_FIELD_NUMBER: builtins.int
    PROFILES_ORIGIN_GROUPS_FIELD_NUMBER: builtins.int
    PROFILES_RULE_SETS_FIELD_NUMBER: builtins.int
    PROFILES_SECURITY_POLICIES_FIELD_NUMBER: builtins.int
    PROFILES_SECRETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    origin_response_timeout_seconds: builtins.int
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def profiles_custom_domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesCustomDomains]: ...
    @property
    def profiles_afd_endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesAfdEndpoints]: ...
    @property
    def profiles_origin_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesOriginGroups]: ...
    @property
    def profiles_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesRuleSets]: ...
    @property
    def profiles_security_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesSecurityPolicies]: ...
    @property
    def profiles_secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProfilesSecrets]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        origin_response_timeout_seconds: builtins.int = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        profiles_custom_domains: collections.abc.Iterable[global___ProfilesCustomDomains] | None = ...,
        profiles_afd_endpoints: collections.abc.Iterable[global___ProfilesAfdEndpoints] | None = ...,
        profiles_origin_groups: collections.abc.Iterable[global___ProfilesOriginGroups] | None = ...,
        profiles_rule_sets: collections.abc.Iterable[global___ProfilesRuleSets] | None = ...,
        profiles_security_policies: collections.abc.Iterable[global___ProfilesSecurityPolicies] | None = ...,
        profiles_secrets: collections.abc.Iterable[global___ProfilesSecrets] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "origin_response_timeout_seconds", b"origin_response_timeout_seconds", "profiles_afd_endpoints", b"profiles_afd_endpoints", "profiles_custom_domains", b"profiles_custom_domains", "profiles_origin_groups", b"profiles_origin_groups", "profiles_rule_sets", b"profiles_rule_sets", "profiles_secrets", b"profiles_secrets", "profiles_security_policies", b"profiles_security_policies", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___Profiles = Profiles

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class CdnWebApplicationFirewallPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_RULES_FIELD_NUMBER: builtins.int
    MANAGED_RULES_FIELD_NUMBER: builtins.int
    POLICY_SETTINGS_FIELD_NUMBER: builtins.int
    RATE_LIMIT_RULES_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def custom_rules(self) -> global___CustomRuleList: ...
    @property
    def managed_rules(self) -> global___ManagedRuleSetList: ...
    @property
    def policy_settings(self) -> global___PolicySettings: ...
    @property
    def rate_limit_rules(self) -> global___RateLimitRuleList: ...
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        custom_rules: global___CustomRuleList | None = ...,
        managed_rules: global___ManagedRuleSetList | None = ...,
        policy_settings: global___PolicySettings | None = ...,
        rate_limit_rules: global___RateLimitRuleList | None = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_rules", b"custom_rules", "managed_rules", b"managed_rules", "policy_settings", b"policy_settings", "rate_limit_rules", b"rate_limit_rules", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_rules", b"custom_rules", "etag", b"etag", "location", b"location", "managed_rules", b"managed_rules", "name", b"name", "policy_settings", b"policy_settings", "rate_limit_rules", b"rate_limit_rules", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___CdnWebApplicationFirewallPolicies = CdnWebApplicationFirewallPolicies

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class RateLimitRuleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RateLimitRule]: ...
    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[global___RateLimitRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rules", b"rules"]) -> None: ...

global___RateLimitRuleList = RateLimitRuleList

@typing_extensions.final
class RateLimitRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    MATCH_CONDITIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RATE_LIMIT_DURATION_IN_MINUTES_FIELD_NUMBER: builtins.int
    RATE_LIMIT_THRESHOLD_FIELD_NUMBER: builtins.int
    action: builtins.str
    enabled_state: builtins.str
    @property
    def match_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchCondition]: ...
    name: builtins.str
    priority: builtins.int
    rate_limit_duration_in_minutes: builtins.int
    rate_limit_threshold: builtins.int
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        enabled_state: builtins.str = ...,
        match_conditions: collections.abc.Iterable[global___MatchCondition] | None = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        rate_limit_duration_in_minutes: builtins.int = ...,
        rate_limit_threshold: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "enabled_state", b"enabled_state", "match_conditions", b"match_conditions", "name", b"name", "priority", b"priority", "rate_limit_duration_in_minutes", b"rate_limit_duration_in_minutes", "rate_limit_threshold", b"rate_limit_threshold"]) -> None: ...

global___RateLimitRule = RateLimitRule

@typing_extensions.final
class PolicySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_CUSTOM_BLOCK_RESPONSE_BODY_FIELD_NUMBER: builtins.int
    DEFAULT_CUSTOM_BLOCK_RESPONSE_STATUS_CODE_FIELD_NUMBER: builtins.int
    DEFAULT_REDIRECT_URL_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    default_custom_block_response_body: builtins.str
    default_custom_block_response_status_code: builtins.int
    default_redirect_url: builtins.str
    enabled_state: builtins.str
    mode: builtins.str
    def __init__(
        self,
        *,
        default_custom_block_response_body: builtins.str = ...,
        default_custom_block_response_status_code: builtins.int = ...,
        default_redirect_url: builtins.str = ...,
        enabled_state: builtins.str = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_custom_block_response_body", b"default_custom_block_response_body", "default_custom_block_response_status_code", b"default_custom_block_response_status_code", "default_redirect_url", b"default_redirect_url", "enabled_state", b"enabled_state", "mode", b"mode"]) -> None: ...

global___PolicySettings = PolicySettings

@typing_extensions.final
class ManagedRuleSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RULE_SETS_FIELD_NUMBER: builtins.int
    @property
    def managed_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleSet]: ...
    def __init__(
        self,
        *,
        managed_rule_sets: collections.abc.Iterable[global___ManagedRuleSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_rule_sets", b"managed_rule_sets"]) -> None: ...

global___ManagedRuleSetList = ManagedRuleSetList

@typing_extensions.final
class ManagedRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANOMALY_SCORE_FIELD_NUMBER: builtins.int
    RULE_GROUP_OVERRIDES_FIELD_NUMBER: builtins.int
    RULE_SET_TYPE_FIELD_NUMBER: builtins.int
    RULE_SET_VERSION_FIELD_NUMBER: builtins.int
    anomaly_score: builtins.int
    @property
    def rule_group_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleGroupOverride]: ...
    rule_set_type: builtins.str
    rule_set_version: builtins.str
    def __init__(
        self,
        *,
        anomaly_score: builtins.int = ...,
        rule_group_overrides: collections.abc.Iterable[global___ManagedRuleGroupOverride] | None = ...,
        rule_set_type: builtins.str = ...,
        rule_set_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anomaly_score", b"anomaly_score", "rule_group_overrides", b"rule_group_overrides", "rule_set_type", b"rule_set_type", "rule_set_version", b"rule_set_version"]) -> None: ...

global___ManagedRuleSet = ManagedRuleSet

@typing_extensions.final
class ManagedRuleGroupOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_GROUP_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    rule_group_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedRuleOverride]: ...
    def __init__(
        self,
        *,
        rule_group_name: builtins.str = ...,
        rules: collections.abc.Iterable[global___ManagedRuleOverride] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rule_group_name", b"rule_group_name", "rules", b"rules"]) -> None: ...

global___ManagedRuleGroupOverride = ManagedRuleGroupOverride

@typing_extensions.final
class ManagedRuleOverride(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    RULE_ID_FIELD_NUMBER: builtins.int
    action: builtins.str
    enabled_state: builtins.str
    rule_id: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        enabled_state: builtins.str = ...,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "enabled_state", b"enabled_state", "rule_id", b"rule_id"]) -> None: ...

global___ManagedRuleOverride = ManagedRuleOverride

@typing_extensions.final
class CustomRuleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomRule]: ...
    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[global___CustomRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rules", b"rules"]) -> None: ...

global___CustomRuleList = CustomRuleList

@typing_extensions.final
class CustomRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ENABLED_STATE_FIELD_NUMBER: builtins.int
    MATCH_CONDITIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    action: builtins.str
    enabled_state: builtins.str
    @property
    def match_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MatchCondition]: ...
    name: builtins.str
    priority: builtins.int
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        enabled_state: builtins.str = ...,
        match_conditions: collections.abc.Iterable[global___MatchCondition] | None = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "enabled_state", b"enabled_state", "match_conditions", b"match_conditions", "name", b"name", "priority", b"priority"]) -> None: ...

global___CustomRule = CustomRule

@typing_extensions.final
class MatchCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_VALUE_FIELD_NUMBER: builtins.int
    MATCH_VARIABLE_FIELD_NUMBER: builtins.int
    NEGATE_CONDITION_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TRANSFORMS_FIELD_NUMBER: builtins.int
    @property
    def match_value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    match_variable: builtins.str
    negate_condition: builtins.bool
    operator: builtins.str
    selector: builtins.str
    @property
    def transforms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        match_value: collections.abc.Iterable[builtins.str] | None = ...,
        match_variable: builtins.str = ...,
        negate_condition: builtins.bool = ...,
        operator: builtins.str = ...,
        selector: builtins.str = ...,
        transforms: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_value", b"match_value", "match_variable", b"match_variable", "negate_condition", b"negate_condition", "operator", b"operator", "selector", b"selector", "transforms", b"transforms"]) -> None: ...

global___MatchCondition = MatchCondition



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_disk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agcp/gcp_compute_disk.proto\x12\x1coak9.tython.gcp.compute_disk\x1a\x13shared/shared.proto\"|\n\x1d\x43omputeDiskXDiskEncryptionKey\x12\x19\n\x11kms_key_self_link\x18\x01 \x01(\t\x12\x1f\n\x17kms_key_service_account\x18\x02 \x01(\t\x12\x0f\n\x07raw_key\x18\x03 \x01(\t\x12\x0e\n\x06sha256\x18\x04 \x01(\t\"\x83\x01\n$ComputeDiskXSourceImageEncryptionKey\x12\x19\n\x11kms_key_self_link\x18\x01 \x01(\t\x12\x1f\n\x17kms_key_service_account\x18\x02 \x01(\t\x12\x0f\n\x07raw_key\x18\x03 \x01(\t\x12\x0e\n\x06sha256\x18\x04 \x01(\t\"\x86\x01\n\'ComputeDiskXSourceSnapshotEncryptionKey\x12\x19\n\x11kms_key_self_link\x18\x01 \x01(\t\x12\x1f\n\x17kms_key_service_account\x18\x02 \x01(\t\x12\x0f\n\x07raw_key\x18\x03 \x01(\t\x12\x0e\n\x06sha256\x18\x04 \x01(\t\"F\n\x14\x43omputeDiskXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x07\n\x0b\x43omputeDisk\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x05 \x01(\t\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32\x35.oak9.tython.gcp.compute_disk.ComputeDisk.LabelsEntry\x12\x1d\n\x15last_attach_timestamp\x18\x07 \x01(\t\x12\x1d\n\x15last_detach_timestamp\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12!\n\x19physical_block_size_bytes\x18\n \x01(\x01\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x18\n\x10provisioned_iops\x18\x0c \x01(\x01\x12\x11\n\tself_link\x18\r \x01(\t\x12\x0c\n\x04size\x18\x0e \x01(\x01\x12\x10\n\x08snapshot\x18\x0f \x01(\t\x12\x17\n\x0fsource_image_id\x18\x10 \x01(\t\x12\x1a\n\x12source_snapshot_id\x18\x11 \x01(\t\x12\x0c\n\x04type\x18\x12 \x01(\t\x12\r\n\x05users\x18\x13 \x03(\t\x12\x0c\n\x04zone\x18\x14 \x01(\t\x12X\n\x13\x64isk_encryption_key\x18\x15 \x01(\x0b\x32;.oak9.tython.gcp.compute_disk.ComputeDiskXDiskEncryptionKey\x12g\n\x1bsource_image_encryption_key\x18\x16 \x01(\x0b\x32\x42.oak9.tython.gcp.compute_disk.ComputeDiskXSourceImageEncryptionKey\x12m\n\x1esource_snapshot_encryption_key\x18\x17 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_disk.ComputeDiskXSourceSnapshotEncryptionKey\x12\x44\n\x08timeouts\x18\x18 \x01(\x0b\x32\x32.oak9.tython.gcp.compute_disk.ComputeDiskXTimeouts\x12\x37\n\rresource_info\x18\x19 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x1f\x43omputeDiskIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x88\x02\n\x15\x43omputeDiskIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12P\n\tcondition\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.compute_disk.ComputeDiskIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1e\x43omputeDiskIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x85\x02\n\x14\x43omputeDiskIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12O\n\tcondition\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.compute_disk.ComputeDiskIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x14\x43omputeDiskIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"N\n,ComputeDiskResourcePolicyAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x83\x02\n#ComputeDiskResourcePolicyAttachment\x12\x0c\n\x04\x64isk\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12\\\n\x08timeouts\x18\x06 \x01(\x0b\x32J.oak9.tython.gcp.compute_disk.ComputeDiskResourcePolicyAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_disk_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEDISK_LABELSENTRY._options = None
  _COMPUTEDISK_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEDISKXDISKENCRYPTIONKEY._serialized_start=81
  _COMPUTEDISKXDISKENCRYPTIONKEY._serialized_end=205
  _COMPUTEDISKXSOURCEIMAGEENCRYPTIONKEY._serialized_start=208
  _COMPUTEDISKXSOURCEIMAGEENCRYPTIONKEY._serialized_end=339
  _COMPUTEDISKXSOURCESNAPSHOTENCRYPTIONKEY._serialized_start=342
  _COMPUTEDISKXSOURCESNAPSHOTENCRYPTIONKEY._serialized_end=476
  _COMPUTEDISKXTIMEOUTS._serialized_start=478
  _COMPUTEDISKXTIMEOUTS._serialized_end=548
  _COMPUTEDISK._serialized_start=551
  _COMPUTEDISK._serialized_end=1519
  _COMPUTEDISK_LABELSENTRY._serialized_start=1474
  _COMPUTEDISK_LABELSENTRY._serialized_end=1519
  _COMPUTEDISKIAMBINDINGXCONDITION._serialized_start=1521
  _COMPUTEDISKIAMBINDINGXCONDITION._serialized_end=1610
  _COMPUTEDISKIAMBINDING._serialized_start=1613
  _COMPUTEDISKIAMBINDING._serialized_end=1877
  _COMPUTEDISKIAMMEMBERXCONDITION._serialized_start=1879
  _COMPUTEDISKIAMMEMBERXCONDITION._serialized_end=1967
  _COMPUTEDISKIAMMEMBER._serialized_start=1970
  _COMPUTEDISKIAMMEMBER._serialized_end=2231
  _COMPUTEDISKIAMPOLICY._serialized_start=2234
  _COMPUTEDISKIAMPOLICY._serialized_end=2405
  _COMPUTEDISKRESOURCEPOLICYATTACHMENTXTIMEOUTS._serialized_start=2407
  _COMPUTEDISKRESOURCEPOLICYATTACHMENTXTIMEOUTS._serialized_end=2485
  _COMPUTEDISKRESOURCEPOLICYATTACHMENT._serialized_start=2488
  _COMPUTEDISKRESOURCEPOLICYATTACHMENT._serialized_end=2747
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_RecoveryServices_Backup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAULTS_BACKUPCONFIG_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_ENCRYPTION_CONFIGS_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_FABRICS_BACKUP_PROTECTION_INTENT_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_FABRICS_PROTECTION_CONTAINERS_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_POLICIES_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_RESOURCE_GUARD_PROXIES_FIELD_NUMBER: builtins.int
    VAULTS_BACKUPSTORAGECONFIG_FIELD_NUMBER: builtins.int
    VAULTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def vaults_backupconfig(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupconfig]: ...
    @property
    def vaults_backup_encryption_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupEncryptionConfigs]: ...
    @property
    def vaults_backup_fabrics_backup_protection_intent(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupFabricsBackupProtectionIntent]: ...
    @property
    def vaults_backup_fabrics_protection_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupFabricsProtectionContainers]: ...
    @property
    def vaults_backup_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupPolicies]: ...
    @property
    def vaults_backup_resource_guard_proxies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupResourceGuardProxies]: ...
    @property
    def vaults_backupstorageconfig(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupstorageconfig]: ...
    @property
    def vaults_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        vaults_backupconfig: collections.abc.Iterable[global___VaultsBackupconfig] | None = ...,
        vaults_backup_encryption_configs: collections.abc.Iterable[global___VaultsBackupEncryptionConfigs] | None = ...,
        vaults_backup_fabrics_backup_protection_intent: collections.abc.Iterable[global___VaultsBackupFabricsBackupProtectionIntent] | None = ...,
        vaults_backup_fabrics_protection_containers: collections.abc.Iterable[global___VaultsBackupFabricsProtectionContainers] | None = ...,
        vaults_backup_policies: collections.abc.Iterable[global___VaultsBackupPolicies] | None = ...,
        vaults_backup_resource_guard_proxies: collections.abc.Iterable[global___VaultsBackupResourceGuardProxies] | None = ...,
        vaults_backupstorageconfig: collections.abc.Iterable[global___VaultsBackupstorageconfig] | None = ...,
        vaults_private_endpoint_connections: collections.abc.Iterable[global___VaultsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vaults_backup_encryption_configs", b"vaults_backup_encryption_configs", "vaults_backup_fabrics_backup_protection_intent", b"vaults_backup_fabrics_backup_protection_intent", "vaults_backup_fabrics_protection_containers", b"vaults_backup_fabrics_protection_containers", "vaults_backup_policies", b"vaults_backup_policies", "vaults_backup_resource_guard_proxies", b"vaults_backup_resource_guard_proxies", "vaults_backupconfig", b"vaults_backupconfig", "vaults_backupstorageconfig", b"vaults_backupstorageconfig", "vaults_private_endpoint_connections", b"vaults_private_endpoint_connections"]) -> None: ...

global___Microsoft_RecoveryServices_Backup = Microsoft_RecoveryServices_Backup

@typing_extensions.final
class VaultsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "location", b"location", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___VaultsPrivateEndpointConnections = VaultsPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    action_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        action_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_required", b"action_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class VaultsBackupstorageconfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CROSS_REGION_RESTORE_FLAG_FIELD_NUMBER: builtins.int
    DEDUP_STATE_FIELD_NUMBER: builtins.int
    STORAGE_MODEL_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_STATE_FIELD_NUMBER: builtins.int
    XCOOL_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    cross_region_restore_flag: builtins.bool
    dedup_state: builtins.str
    storage_model_type: builtins.str
    storage_type: builtins.str
    storage_type_state: builtins.str
    xcool_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        cross_region_restore_flag: builtins.bool = ...,
        dedup_state: builtins.str = ...,
        storage_model_type: builtins.str = ...,
        storage_type: builtins.str = ...,
        storage_type_state: builtins.str = ...,
        xcool_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cross_region_restore_flag", b"cross_region_restore_flag", "dedup_state", b"dedup_state", "e_tag", b"e_tag", "location", b"location", "name", b"name", "resource_info", b"resource_info", "storage_model_type", b"storage_model_type", "storage_type", b"storage_type", "storage_type_state", b"storage_type_state", "tags", b"tags", "xcool_state", b"xcool_state"]) -> None: ...

global___VaultsBackupstorageconfig = VaultsBackupstorageconfig

@typing_extensions.final
class VaultsBackupResourceGuardProxies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VaultsBackupResourceGuardProxies = VaultsBackupResourceGuardProxies

@typing_extensions.final
class VaultsBackupPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROTECTED_ITEMS_COUNT_FIELD_NUMBER: builtins.int
    RESOURCE_GUARD_OPERATION_REQUESTS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    protected_items_count: builtins.int
    @property
    def resource_guard_operation_requests(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        protected_items_count: builtins.int = ...,
        resource_guard_operation_requests: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "location", b"location", "name", b"name", "protected_items_count", b"protected_items_count", "resource_guard_operation_requests", b"resource_guard_operation_requests", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___VaultsBackupPolicies = VaultsBackupPolicies

@typing_extensions.final
class VaultsBackupFabricsProtectionContainersProtectedItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKUP_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    BACKUP_SET_NAME_FIELD_NUMBER: builtins.int
    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    DEFERRED_DELETE_TIME_IN_U_T_C_FIELD_NUMBER: builtins.int
    DEFERRED_DELETE_TIME_REMAINING_FIELD_NUMBER: builtins.int
    IS_ARCHIVE_ENABLED_FIELD_NUMBER: builtins.int
    IS_DEFERRED_DELETE_SCHEDULE_UPCOMING_FIELD_NUMBER: builtins.int
    IS_REHYDRATE_FIELD_NUMBER: builtins.int
    IS_SCHEDULED_FOR_DEFERRED_DELETE_FIELD_NUMBER: builtins.int
    LAST_RECOVERY_POINT_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GUARD_OPERATION_REQUESTS_FIELD_NUMBER: builtins.int
    SOURCE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    WORKLOAD_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    backup_management_type: builtins.str
    backup_set_name: builtins.str
    container_name: builtins.str
    create_mode: builtins.str
    deferred_delete_time_in_u_t_c: builtins.str
    deferred_delete_time_remaining: builtins.str
    is_archive_enabled: builtins.bool
    is_deferred_delete_schedule_upcoming: builtins.bool
    is_rehydrate: builtins.bool
    is_scheduled_for_deferred_delete: builtins.bool
    last_recovery_point: builtins.str
    policy_id: builtins.str
    policy_name: builtins.str
    @property
    def resource_guard_operation_requests(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    source_resource_id: builtins.str
    workload_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backup_management_type: builtins.str = ...,
        backup_set_name: builtins.str = ...,
        container_name: builtins.str = ...,
        create_mode: builtins.str = ...,
        deferred_delete_time_in_u_t_c: builtins.str = ...,
        deferred_delete_time_remaining: builtins.str = ...,
        is_archive_enabled: builtins.bool = ...,
        is_deferred_delete_schedule_upcoming: builtins.bool = ...,
        is_rehydrate: builtins.bool = ...,
        is_scheduled_for_deferred_delete: builtins.bool = ...,
        last_recovery_point: builtins.str = ...,
        policy_id: builtins.str = ...,
        policy_name: builtins.str = ...,
        resource_guard_operation_requests: collections.abc.Iterable[builtins.str] | None = ...,
        source_resource_id: builtins.str = ...,
        workload_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_management_type", b"backup_management_type", "backup_set_name", b"backup_set_name", "container_name", b"container_name", "create_mode", b"create_mode", "deferred_delete_time_in_u_t_c", b"deferred_delete_time_in_u_t_c", "deferred_delete_time_remaining", b"deferred_delete_time_remaining", "e_tag", b"e_tag", "is_archive_enabled", b"is_archive_enabled", "is_deferred_delete_schedule_upcoming", b"is_deferred_delete_schedule_upcoming", "is_rehydrate", b"is_rehydrate", "is_scheduled_for_deferred_delete", b"is_scheduled_for_deferred_delete", "last_recovery_point", b"last_recovery_point", "location", b"location", "name", b"name", "policy_id", b"policy_id", "policy_name", b"policy_name", "resource_guard_operation_requests", b"resource_guard_operation_requests", "resource_info", b"resource_info", "source_resource_id", b"source_resource_id", "tags", b"tags", "workload_type", b"workload_type"]) -> None: ...

global___VaultsBackupFabricsProtectionContainersProtectedItems = VaultsBackupFabricsProtectionContainersProtectedItems

@typing_extensions.final
class VaultsBackupFabricsProtectionContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKUP_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    FRIENDLY_NAME_FIELD_NUMBER: builtins.int
    HEALTH_STATUS_FIELD_NUMBER: builtins.int
    PROTECTABLE_OBJECT_TYPE_FIELD_NUMBER: builtins.int
    REGISTRATION_STATUS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VAULTS_BACKUP_FABRICS_PROTECTION_CONTAINERS_PROTECTED_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    backup_management_type: builtins.str
    friendly_name: builtins.str
    health_status: builtins.str
    protectable_object_type: builtins.str
    registration_status: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vaults_backup_fabrics_protection_containers_protected_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsBackupFabricsProtectionContainersProtectedItems]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backup_management_type: builtins.str = ...,
        friendly_name: builtins.str = ...,
        health_status: builtins.str = ...,
        protectable_object_type: builtins.str = ...,
        registration_status: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vaults_backup_fabrics_protection_containers_protected_items: collections.abc.Iterable[global___VaultsBackupFabricsProtectionContainersProtectedItems] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_management_type", b"backup_management_type", "e_tag", b"e_tag", "friendly_name", b"friendly_name", "health_status", b"health_status", "location", b"location", "name", b"name", "protectable_object_type", b"protectable_object_type", "registration_status", b"registration_status", "resource_info", b"resource_info", "tags", b"tags", "vaults_backup_fabrics_protection_containers_protected_items", b"vaults_backup_fabrics_protection_containers_protected_items"]) -> None: ...

global___VaultsBackupFabricsProtectionContainers = VaultsBackupFabricsProtectionContainers

@typing_extensions.final
class VaultsBackupFabricsBackupProtectionIntent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BACKUP_MANAGEMENT_TYPE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROTECTION_STATE_FIELD_NUMBER: builtins.int
    SOURCE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    backup_management_type: builtins.str
    item_id: builtins.str
    policy_id: builtins.str
    protection_state: builtins.str
    source_resource_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        backup_management_type: builtins.str = ...,
        item_id: builtins.str = ...,
        policy_id: builtins.str = ...,
        protection_state: builtins.str = ...,
        source_resource_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_management_type", b"backup_management_type", "e_tag", b"e_tag", "item_id", b"item_id", "location", b"location", "name", b"name", "policy_id", b"policy_id", "protection_state", b"protection_state", "resource_info", b"resource_info", "source_resource_id", b"source_resource_id", "tags", b"tags"]) -> None: ...

global___VaultsBackupFabricsBackupProtectionIntent = VaultsBackupFabricsBackupProtectionIntent

@typing_extensions.final
class VaultsBackupEncryptionConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENCRYPTION_AT_REST_TYPE_FIELD_NUMBER: builtins.int
    INFRASTRUCTURE_ENCRYPTION_STATE_FIELD_NUMBER: builtins.int
    KEY_URI_FIELD_NUMBER: builtins.int
    LAST_UPDATE_STATUS_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    encryption_at_rest_type: builtins.str
    infrastructure_encryption_state: builtins.str
    key_uri: builtins.str
    last_update_status: builtins.str
    subscription_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        encryption_at_rest_type: builtins.str = ...,
        infrastructure_encryption_state: builtins.str = ...,
        key_uri: builtins.str = ...,
        last_update_status: builtins.str = ...,
        subscription_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "encryption_at_rest_type", b"encryption_at_rest_type", "infrastructure_encryption_state", b"infrastructure_encryption_state", "key_uri", b"key_uri", "last_update_status", b"last_update_status", "location", b"location", "name", b"name", "resource_info", b"resource_info", "subscription_id", b"subscription_id", "tags", b"tags"]) -> None: ...

global___VaultsBackupEncryptionConfigs = VaultsBackupEncryptionConfigs

@typing_extensions.final
class VaultsBackupconfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENHANCED_SECURITY_STATE_FIELD_NUMBER: builtins.int
    IS_SOFT_DELETE_FEATURE_STATE_EDITABLE_FIELD_NUMBER: builtins.int
    RESOURCE_GUARD_OPERATION_REQUESTS_FIELD_NUMBER: builtins.int
    SOFT_DELETE_FEATURE_STATE_FIELD_NUMBER: builtins.int
    STORAGE_MODEL_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_FIELD_NUMBER: builtins.int
    STORAGE_TYPE_STATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    e_tag: builtins.str
    location: builtins.str
    name: builtins.str
    enhanced_security_state: builtins.str
    is_soft_delete_feature_state_editable: builtins.bool
    @property
    def resource_guard_operation_requests(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    soft_delete_feature_state: builtins.str
    storage_model_type: builtins.str
    storage_type: builtins.str
    storage_type_state: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        e_tag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        enhanced_security_state: builtins.str = ...,
        is_soft_delete_feature_state_editable: builtins.bool = ...,
        resource_guard_operation_requests: collections.abc.Iterable[builtins.str] | None = ...,
        soft_delete_feature_state: builtins.str = ...,
        storage_model_type: builtins.str = ...,
        storage_type: builtins.str = ...,
        storage_type_state: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["e_tag", b"e_tag", "enhanced_security_state", b"enhanced_security_state", "is_soft_delete_feature_state_editable", b"is_soft_delete_feature_state_editable", "location", b"location", "name", b"name", "resource_guard_operation_requests", b"resource_guard_operation_requests", "resource_info", b"resource_info", "soft_delete_feature_state", b"soft_delete_feature_state", "storage_model_type", b"storage_model_type", "storage_type", b"storage_type", "storage_type_state", b"storage_type_state", "tags", b"tags"]) -> None: ...

global___VaultsBackupconfig = VaultsBackupconfig



def check_transparent_data_encryption_aks(aks, context):
    """
    Temp disks and cache for agent node pools in Azure Kubernetes Service clusters should be encrypted at host.

    To enhance data security, the data stored on the virtual machine (VM) host of your Azure Kubernetes Service
    nodes VMs should be encrypted at rest. This is a common requirement in many regulatory and industry compliance
    standards.

    Implements:
        AZURE_POLICY: https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json
        KUBE_BENCH: https://github.com/aquasecurity/blob/master/kube-bench/cfg/cis-1.6/master.yaml
    Coverage:
        Partial:
            TODO (atcherniakhovski): Validate that this handles the case of multiple node-pools.
    """
    violations = []

    return violations


from setuptools import setup, find_packages

package_data = {}

for package in find_packages():
    package_data[package] = ["*.pyi"]

setup_args = dict(
    name='oak9.tython',
    version='1.0.1',
    description='oak9 tython framework',
    license='Open Source',
    packages=find_packages(),
    package_data=package_data,
    author='oak9',
    author_email='oak9@oak9.io'
)

if __name__ == '__main__':
    setup(**setup_args)
